#[repr(C)]pub struct DeviceGetEventResponse {
pub event: Event,
}Expand description
The wire type corresponding to DeviceGetEventResponse.
Fields
event: EventTrait Implementations
Sourceimpl Constrained for DeviceGetEventResponse
impl Constrained for DeviceGetEventResponse
Sourceimpl Debug for DeviceGetEventResponse
impl Debug for DeviceGetEventResponse
Sourceimpl<___D> Decode<___D> for DeviceGetEventResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for DeviceGetEventResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<DeviceGetEventResponse, ___E> for DeviceGetEventResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<DeviceGetEventResponse, ___E> for DeviceGetEventResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetEventResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetEventResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetEventResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetEventResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceGetEventResponse, ___E> for DeviceGetEventResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Event, ___E>,
impl<___E, T0> Encode<DeviceGetEventResponse, ___E> for DeviceGetEventResponse<T0>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Event, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetEventResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetEventResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceGetEventResponse> for DeviceGetEventResponse
impl FromWire<DeviceGetEventResponse> for DeviceGetEventResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetEventResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetEventResponse, Self>
Sourcefn from_wire(wire: DeviceGetEventResponse) -> Self
fn from_wire(wire: DeviceGetEventResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for DeviceGetEventResponse
impl IntoNatural for DeviceGetEventResponse
Sourcetype Natural = DeviceGetEventResponse
type Natural = DeviceGetEventResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetEventResponse
impl Wire for DeviceGetEventResponse
Sourcetype Narrowed<'de> = DeviceGetEventResponse
type Narrowed<'de> = DeviceGetEventResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.